@@ -58,6 +58,18 @@ class Scraper:
         # return data by retrieving the tag content
         return ' '.join(self._soup.stripped_strings)
 
+    def gethref(self) -> List:
+        """
+        Returns a list of links
+        """
+        links = List(str)
+        for link in self._soup.findAll('a'):
+            links.append(link.get('href'))
+        return links
+
+
+
+
     def __str__(self):
         return f"""
         title = {self.title}
